# Changelog

## [0.4.1](https://github.com/nicholasraimbault/skytale/compare/sdk-v0.4.0...sdk-v0.4.1) (2026-03-06)


### Bug Fixes

* **sdk:** rename npm scope from [@skytale](https://github.com/skytale) to [@skytalesh](https://github.com/skytalesh) ([ffff0fb](https://github.com/nicholasraimbault/skytale/commit/ffff0fb89bcd646e9a6db0919be70bf7c05100bd))
